(api-ref)=

```{eval-rst}
.. currentmodule:: pySPFM
```

# API

(api-pyspfm-ref)=

## {mod}`pySPFM.workflows`: The main pySPFM workflow

```{eval-rst}
.. automodule:: pySPFM.workflows
   :no-members:
   :no-inherited-members:
```

```{eval-rst}
.. currentmodule:: pySPFM.workflows
```

```{eval-rst}
.. autosummary::
   :toctree: generated/
   :template: module.rst

   pySPFM.workflows.pySPFM
   pySPFM.workflows.auc_to_estimates
```

(api-deconvolution-ref)=

## {mod}`pySPFM.deconvolution`: Deconvolution methods

```{eval-rst}
.. automodule:: pySPFM.deconvolution
   :no-members:
   :no-inherited-members:
```

```{eval-rst}
.. currentmodule:: pySPFM.deconvolution
```

```{eval-rst}
.. autosummary::
   :toctree: generated/
   :template: function.rst

   pySPFM.deconvolution.debiasing
   pySPFM.deconvolution.fista
   pySPFM.deconvolution.hrf_generator
   pySPFM.deconvolution.lars
   pySPFM.deconvolution.select_lambda
   pySPFM.deconvolution.spatial_regularization
   pySPFM.deconvolution.stability_selection

```

(api-io-ref)=

## {mod}`pySPFM.io`: Input/Output methods

```{eval-rst}
.. automodule:: pySPFM.io
   :no-members:
   :no-inherited-members:
```

```{eval-rst}
.. currentmodule:: pySPFM.io
```

```{eval-rst}
.. autosummary::
   :toctree: generated/
   :template: function.rst

   pySPFM.io.read_data
   pySPFM.io.update_header
   pySPFM.io.write_data
   pySPFM.io.write_json

```

(api-utils-ref)=

## {mod}`pySPFM.utils`: Miscellaneous utility methods

```{eval-rst}
.. automodule:: pySPFM.utils
   :no-members:
   :no-inherited-members:
```

```{eval-rst}
.. currentmodule:: pySPFM.utils
```

```{eval-rst}
.. autosummary::
   :toctree: generated/
   :template: module.rst

   pySPFM.utils.setup_loggers
   pySPFM.utils.teardown_loggers
```
